@@ -266,6 +266,9 @@ INVALIDPARAMETER_INVALIDJOBFLOW = 'InvalidParameter.InvalidJobFlow'
 # 无效的任务步骤类型。
 INVALIDPARAMETER_INVALIDJOBTYPE = 'InvalidParameter.InvalidJobType'
 
+# 不合法的LoadBalancerId
+INVALIDPARAMETER_INVALIDLOADBALANCER = 'InvalidParameter.InvalidLoadBalancer'
+
 # 无效的登录设置。
 INVALIDPARAMETER_INVALIDLOGINSETTING = 'InvalidParameter.InvalidLoginSetting'
 
