@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -32,6 +32,18 @@ FAILEDOPERATION = 'FailedOperation'
 # 云端录制方法不支持。
 FAILEDOPERATION_CRUNSUPPORTMETHOD = 'FailedOperation.CRUnsupportMethod'
 
+# 云端切片方法不支持。
+FAILEDOPERATION_CSUNSUPPORTMETHOD = 'FailedOperation.CSUnsupportMethod'
+
+# Cos上传出现异常。
+FAILEDOPERATION_COSOPERATIONFAILED = 'FailedOperation.CosOperationFailed'
+
+# 数据库处理出现异常。
+FAILEDOPERATION_DBOPERATIONFAILED = 'FailedOperation.DbOperationFailed'
+
+# VoicePrintId生成出现异常。
+FAILEDOPERATION_GENVOICEPRINTIDFAILED = 'FailedOperation.GenVoicePrintIdFailed'
+
 # 房间中没有设置混流模板。
 FAILEDOPERATION_MIXSESSIONNOTEXIST = 'FailedOperation.MixSessionNotExist'
 
@@ -71,12 +83,24 @@ FAILEDOPERATION_TASKFINISHED = 'FailedOperation.TaskFinished'
 # 任务不存在或已结束
 FAILEDOPERATION_TASKNOTEXIST = 'FailedOperation.TaskNotExist'
 
+# VoicePrintId不存在。
+FAILEDOPERATION_UPDATEVOICEPRINTIDNOTFOUND = 'FailedOperation.UpdateVoicePrintIdNotFound'
+
+# 声纹音频检测出现异常。
+FAILEDOPERATION_VOICEPRINTAUDIOCHECKFAILED = 'FailedOperation.VoicePrintAudioCheckFailed'
+
+# 单用户声纹注册数量受限,请联系我们调整到合理值。
+FAILEDOPERATION_VOICEPRINTREGISTRATIONLIMIT = 'FailedOperation.VoicePrintRegistrationLimit'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
 # 云端录制内部服务错误。
 INTERNALERROR_CRINTERNALERROR = 'InternalError.CRInternalError'
 
+# 云端切片内部服务错误
+INTERNALERROR_CSINTERNALERROR = 'InternalError.CSInternalError'
+
 # 数据库查询异常。
 INTERNALERROR_DBERROR = 'InternalError.DBError'
 
@@ -113,6 +137,9 @@ INVALIDPARAMETER_APPID = 'InvalidParameter.AppId'
 # 音频编码参数错误。
 INVALIDPARAMETER_AUDIOENCODEPARAMS = 'InvalidParameter.AudioEncodeParams'
 
+# 无效的参考音频
+INVALIDPARAMETER_AUDIOPROMPT = 'InvalidParameter.AudioPrompt'
+
 # BackgroundImageUrl参数错误。
 INVALIDPARAMETER_BACKGROUNDIMAGEURL = 'InvalidParameter.BackgroundImageUrl'
 
@@ -131,9 +158,15 @@ INVALIDPARAMETER_ENCODEPARAMS = 'InvalidParameter.EncodeParams'
 # EndTs参数错误。
 INVALIDPARAMETER_ENDTS = 'InvalidParameter.EndTs'
 
+# Audio 参数不合法。
+INVALIDPARAMETER_INVALIDAUDIOINPUT = 'InvalidParameter.InvalidAudioInput'
+
 # invalid sdkAppId
 INVALIDPARAMETER_INVALIDSDKAPPID = 'InvalidParameter.InvalidSdkAppId'
 
+# VoicePrintIdList 不能为空，也不能过长。
+INVALIDPARAMETER_INVALIDVOICEPRINTIDLIST = 'InvalidParameter.InvalidVoicePrintIdList'
+
 # 大画面居右显示参数错误。
 INVALIDPARAMETER_MAINVIDEORIGHTALIGN = 'InvalidParameter.MainVideoRightAlign'
 
@@ -212,6 +245,9 @@ INVALIDPARAMETER_STREAMURL = 'InvalidParameter.StreamUrl'
 # TaskId 参数错误。
 INVALIDPARAMETER_TASKID = 'InvalidParameter.TaskId'
 
+# 无效的文本长度
+INVALIDPARAMETER_TEXTLENGTH = 'InvalidParameter.TextLength'
+
 # Url解析参数失败。
 INVALIDPARAMETER_URLPARAMSERROR = 'InvalidParameter.UrlParamsError'
 
@@ -233,12 +269,21 @@ INVALIDPARAMETER_USERSIGNOTADMIN = 'InvalidParameter.UserSigNotAdmin'
 # 视频分辨率参数错误。
 INVALIDPARAMETER_VIDEORESOLUTION = 'InvalidParameter.VideoResolution'
 
+# 无效的VoiceId
+INVALIDPARAMETER_VOICEID = 'InvalidParameter.VoiceId'
+
+# 无效的声音名字
+INVALIDPARAMETER_VOICENAME = 'InvalidParameter.VoiceName'
+
 # RoomId值错误。
 INVALIDPARAMETERVALUE_ROOMID = 'InvalidParameterValue.RoomId'
 
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
+# 无效的APIKey
+MISSINGPARAMETER_APIKEY = 'MissingParameter.APIKey'
+
 # 缺少AccessKey参数。
 MISSINGPARAMETER_ACCESSKEY = 'MissingParameter.AccessKey'
 
@@ -269,6 +314,9 @@ MISSINGPARAMETER_ENCODEPARAMS = 'MissingParameter.EncodeParams'
 # 缺少endTS_s参数。
 MISSINGPARAMETER_ENDTS = 'MissingParameter.EndTs'
 
+# 更新声纹时,Audio,AudioName,AudioMetaInfo不能都为空。
+MISSINGPARAMETER_MISSINGVOICEPRINTUPDATEPARAMS = 'MissingParameter.MissingVoicePrintUpdateParams'
+
 # 缺少OutputParams参数。
 MISSINGPARAMETER_OUTPUTPARAMS = 'MissingParameter.OutputParams'
 
@@ -302,6 +350,15 @@ MISSINGPARAMETER_SDKAPPID = 'MissingParameter.SdkAppId'
 # 缺少SecretKey参数。
 MISSINGPARAMETER_SECRETKEY = 'MissingParameter.SecretKey'
 
+# 缺少SliceParams参数。
+MISSINGPARAMETER_SLICEPARAMS = 'MissingParameter.SliceParams'
+
+# 缺少SliceStorageParams参数。
+MISSINGPARAMETER_SLICESTORAGEPARAMS = 'MissingParameter.SliceStorageParams'
+
+# 缺少SliceType参数。
+MISSINGPARAMETER_SLICETYPE = 'MissingParameter.SliceType'
+
 # 缺少startTS_s参数。
 MISSINGPARAMETER_STARTTS = 'MissingParameter.StartTs'
 
@@ -332,6 +389,9 @@ MISSINGPARAMETER_VENDOR = 'MissingParameter.Vendor'
 # EncodeParams中缺少视频输出参数。
 MISSINGPARAMETER_VIDEOENCODEPARAMS = 'MissingParameter.VideoEncodeParams'
 
+# 请求频率超限，请稍后再试
+OPERATIONDENIED_FREQOVERLIMIT = 'OperationDenied.FreqOverLimit'
+
 # 资源不足。
 RESOURCEINSUFFICIENT_REQUESTREJECTION = 'ResourceInsufficient.RequestRejection'
 
@@ -346,3 +406,6 @@ UNKNOWNPARAMETER = 'UnknownParameter'
 
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
+
+# 不允许使用，请联系技术人员
+UNSUPPORTEDOPERATION_NOTALLOWED = 'UnsupportedOperation.NotAllowed'
